@@ -39,6 +39,7 @@ from JNIFrameWork import JNIFrameWork
 from datatypes.dataGiws import dataGiws
 from datatypes.stringDataGiws import stringDataGiws
 from types import MethodType
+from configGiws import configGiws
 
 class methodGiws:
 	__name=""
@@ -135,8 +136,9 @@ class methodGiws:
 	def getUniqueNameOfTheMethod(self):
 		paramStr=""
 		for parameter in self.getParameters(): #Creates a unique string of all the profiles
-			paramStr+=parameter.getType().getJavaTypeSyntax() 
-		str="""%s%s%sID"""%(self.getReturn().getJavaTypeSyntax(), self.getName(), paramStr)
+			paramStr+=parameter.getType().getJavaTypeSyntax() + "_"*parameter.getType().getDimensionArray()
+
+		str="""%s%s%sID"""%(self.getReturn().getJavaTypeSyntax() + "_" * self.getReturn().getDimensionArray(), self.getName(), paramStr)
 		
 
 		return str
@@ -148,17 +150,35 @@ class methodGiws:
                         static="static "
                 else:
                         static=""
-                
-		str="""%s%s %s(%s);
-		"""%(static, self.getReturn().getNativeType(), self.getName(), self.getParametersCXX())
+		
+		ret=""
+		if self.getReturn().isArray() and configGiws().getDisableReturnSize()!=True:
+			if len(self.__parameters)!=0:
+				ret+=", "
+			if self.getReturn().getDimensionArray() == 1:
+				ret+="int *lenRowReturned"
+			else:
+				ret+="int *lenRowReturned, int *lenColReturned"
+
+		str="""%s%s %s(%s%s);
+		"""%(static, self.getReturn().getNativeType(), self.getName(), self.getParametersCXX(),ret)
 		return str
 	 
 	def generateCXXBody(self, className):
 		""" Generates the content of the method ... for the body """
 		baseProfile="""%s %s::%s"""%(self.getReturn().getNativeType(),className, self.getName())
 		
+		ret=""
+		if self.getReturn().isArray() and configGiws().getDisableReturnSize()!=True:
+			if len(self.__parameters)!=0:
+				ret+=", "
+			if self.getReturn().getDimensionArray() == 1:
+				ret+="int *lenRowReturned"
+			else:
+				ret+="int *lenRowReturned, int *lenColReturned"
+
 		str="""
-		%s (%s)"""%(baseProfile,self.getParametersCXX())
+		%s (%s%s)"""%(baseProfile,self.getParametersCXX(),ret)
 			
 		str+="""{
 		%s
