@@ -35,6 +35,7 @@
 # For more information, see the file COPYING
 
 from datatypes.intDataGiws import intDataGiws
+from datatypes.charDataGiws import charDataGiws
 from datatypes.longDataGiws import longDataGiws
 from datatypes.doubleDataGiws import doubleDataGiws
 from datatypes.booleanDataGiws import booleanDataGiws
@@ -52,6 +53,7 @@ class dataFactoryGiws:
 
 		  self.dict = {
 			  "int":    intDataGiws,
+			  "char":    charDataGiws,
 			  "long":   longDataGiws,
 			  "double": doubleDataGiws,
               "boolean": booleanDataGiws,
@@ -64,17 +66,19 @@ class dataFactoryGiws:
 
 	  def create(self, dataTypeToCreate):
             """ Create an GIWS datatype
-            it can be int, long, double, boolean, byte, float, short,
+            it can be int, char, long, double, boolean, byte, float, short,
             String and void
             if there is a trailing [], this object will consider it as an
             array of this data
 
             """
             isArray=False
+            arrayDimension=0 # Scalar
             if dataTypeToCreate.endswith("[]"): # It is an array
                   isArray=True
+                  arrayDimension=dataTypeToCreate.count("[]")
                   # Trim to load the right object
-                  dataTypeToCreate=dataTypeToCreate[0:len(dataTypeToCreate)-2]
+                  dataTypeToCreate=dataTypeToCreate[0:len(dataTypeToCreate)-(arrayDimension*2)]
 
                   
             if dataTypeToCreate not in self.dict:
@@ -82,6 +86,7 @@ class dataFactoryGiws:
             
             myType=self.dict[dataTypeToCreate]()
             myType.setIsArray(isArray)
+            myType.setDimensionArray(arrayDimension)
             return myType
 
 if __name__ == '__main__':
