@@ -39,14 +39,15 @@ from configGiws import configGiws
 from JNIFrameWork import JNIFrameWork
 
 def abstractMethod(obj=None):
-    """ Use this instead of 'pass' for the body of abstract methods. """
-    raise Exception("Unimplemented abstract method: %s" % _functionId(obj, 1))
+	""" Use this instead of 'pass' for the body of abstract methods. """
+	raise Exception("Unimplemented abstract method: %s" % _functionId(obj, 1))
 
 #
 # This class intend to create a generic object for datatype
 # see http://en.wikipedia.org/wiki/Java_Native_Interface#Mapping_types
 class dataGiws(object):
 	__isArray=False
+	__dimensionArray=0
 	"""
 	Interface for the datatype mapping
 	"""
@@ -56,7 +57,10 @@ class dataGiws(object):
 		when applies
 		"""
 		if self.isArray() and not ForceNotArray:
-			return self.type+"Array"
+			if self.getDimensionArray == 1: 
+				return self.type+"Array"
+			else:
+				return "jobjectArray"
 		else:
 			return self.type
 		
@@ -80,7 +84,7 @@ class dataGiws(object):
 		""" Returns the native type (C/C++)
 		"""
 		if self.isArray() and not ForceNotArray:
-			return self.nativeType+" *"
+			return self.nativeType + "*" * self.__dimensionArray
 		else:
 			return self.nativeType
 
@@ -134,6 +138,18 @@ class dataGiws(object):
 		"""
 		return self.__isArray
 
+		
+		
+	def setDimensionArray(self, dimensionArray):
+		""" Defines the size of the array
+		"""
+		self.__dimensionArray=dimensionArray
+
+	def getDimensionArray(self):
+		""" return the size of the array
+		"""
+		return self.__dimensionArray
+
 
 	def __getProfileCreationOfTheArray(self, varName):
 		"""
@@ -153,15 +169,28 @@ class dataGiws(object):
 			}
 			"""%(varName,configGiws().getExceptionFileName())
 		else:
-			errorMgnt=""
-  
-		# Yep, it seems ugly to have that much varName but it is normal.
-		return """
-		%sArray %s_ = curEnv->New%sArray( %sSize ) ;
-		%s
-		curEnv->Set%sArrayRegion( %s_, 0, %sSize, (%s*)(%s) ) ;
+   			errorMgnt=""
 
-		"""%(javaType, varName, shortType, varName, errorMgnt, shortType, varName, varName, javaType, varName) 
+                if self.getDimensionArray() == 1:
+			# Yep, it seems ugly to have that much varName but it is normal.
+			return """
+			%sArray %s_ = curEnv->New%sArray( %sSize ) ;
+			%s
+			curEnv->Set%sArrayRegion( %s_, 0, %sSize, (%s*)(%s) ) ;
+	
+			"""%(javaType, varName, shortType, varName, errorMgnt, shortType, varName, varName, javaType, varName) 
+                else:
+			return """
+			 jobjectArray %s_ = curEnv->NewObjectArray(%sSize, curEnv->FindClass("[%s"),NULL);
+			%s
+			 for (int i=0; i<%sSize; i++){
+ 
+			%sArray %sLocal = curEnv->New%sArray( %sSizeCol ) ;
+			curEnv->Set%sArrayRegion( %sLocal, 0, %sSizeCol, (%s*)(%s[i]) ) ;
+			curEnv->SetObjectArrayElement(%s_, i, %sLocal);
+			curEnv->DeleteLocalRef(%sLocal);
+			}
+			"""%(varName, varName, self.getTypeSignature(), errorMgnt, varName, javaType, varName, shortType, varName, shortType, varName, varName, javaType, varName, varName, varName, varName) 
 
 	def specificPreProcessing(self, parameter):
 		""" Preprocessing before calling the java method
@@ -190,21 +219,49 @@ class dataGiws(object):
 		
 		if self.isArray():
 			str=JNIFrameWork().getExceptionCheckProfile()
-			return str+"""
-			jsize len = curEnv->GetArrayLength(res);
+			strCommon=""
+
+			strCommon+="""			
+			int lenRow = curEnv->GetArrayLength(res);
 			jboolean isCopy = JNI_FALSE;
+			"""
+			if configGiws().getDisableReturnSize()==False:
+				# When the user want the size in the argument
+				strCommon+="""*lenRowReturned=lenRow;"""
+			if self.getDimensionArray() == 1: 
+			  	return str+strCommon+"""
+				/* GetPrimitiveArrayCritical is faster than getXXXArrayElements */
+				%s *resultsArray = static_cast<%s *>(curEnv->GetPrimitiveArrayCritical(res, &isCopy));
+				%s myArray= new %s[lenRow];
+	
+				for (jsize i = 0; i < lenRow; i++){
+				myArray[i]=resultsArray[i];
+				}
+				curEnv->ReleasePrimitiveArrayCritical(res, resultsArray, JNI_ABORT);
 
-			/* faster than getXXXArrayElements */
-			%s *resultsArray = static_cast<%s *>(curEnv->GetPrimitiveArrayCritical(res, &isCopy));
-			%s myArray= new %s[len];
+							curEnv->DeleteLocalRef(res);
+				"""%(javaTypeNotArray, javaTypeNotArray, self.getNativeType(), nativeTypeForceNotArray)
+			else:
+				str+="int lenCol;"
+				if configGiws().getDisableReturnSize()==False:
+					str+="""*lenColReturned=lenCol;"""
 
-			for (jsize i = 0; i < len; i++){
-			myArray[i]=resultsArray[i];
-			}
-			curEnv->ReleasePrimitiveArrayCritical(res, resultsArray, JNI_ABORT);
+				return str+strCommon+"""
+				%s ** myArray = new %s*[lenRow];
+				for(int i=0; i<lenRow; i++) {
+				%sArray oneDim = (%sArray)curEnv->GetObjectArrayElement(res, i);
+				lenCol=curEnv->GetArrayLength(oneDim);
+				%s *resultsArray = static_cast<%s *>(curEnv->GetPrimitiveArrayCritical(oneDim, &isCopy));
+				myArray[i] = new %s[lenCol];
+				for(int j=0; j<lenCol; j++) {
+				myArray[i][j]= resultsArray[j];
+				}
+				curEnv->ReleasePrimitiveArrayCritical(res, resultsArray, JNI_ABORT);
+				}
+ 
+				curEnv->DeleteLocalRef(res);
+				"""%(self.nativeType, self.nativeType, javaTypeNotArray, javaTypeNotArray, self.nativeType, self.nativeType, nativeTypeForceNotArray)
 
-                        curEnv->DeleteLocalRef(res);
-			"""%(javaTypeNotArray, javaTypeNotArray, self.getNativeType(), nativeTypeForceNotArray)
 		else:
 			# Not post processing when dealing with primitive types
 			return ""
