@@ -61,7 +61,7 @@ class stringDataGiws(dataGiws):
 
 	def getNativeType(self):
 		if self.isArray():
-			return "char **"
+			return "char *" + "*" * self.getDimensionArray()
 		else:
 			return "char *"
 
@@ -83,29 +83,61 @@ class stringDataGiws(dataGiws):
 			exit(EXIT_FAILURE);"""
 
 		if self.isArray():
-			return """			
+			if self.getDimensionArray() == 1:
+				return """			
 			
-			// create java array of strings.
-			jobjectArray %s_ = curEnv->NewObjectArray( %sSize, stringArrayClass, NULL);
-			if (%s_ == NULL)
-			{
-			%s
-			}
+				// create java array of strings.
+				jobjectArray %s_ = curEnv->NewObjectArray( %sSize, stringArrayClass, NULL);
+				if (%s_ == NULL)
+				{
+				%s
+				}
 
-			// convert each char * to java strings and fill the java array.
-			for ( int i = 0; i < %sSize; i++)
-			{
-			jstring TempString = curEnv->NewStringUTF( %s[i] );
-			if (TempString == NULL)
-			{
-			%s
-			}
+				// convert each char * to java strings and fill the java array.
+				for ( int i = 0; i < %sSize; i++)
+				{
+				jstring TempString = curEnv->NewStringUTF( %s[i] );
+				if (TempString == NULL)
+				{
+				%s
+				}
 			
-			curEnv->SetObjectArrayElement( %s_, i, TempString);
+				curEnv->SetObjectArrayElement( %s_, i, TempString);
 			
-			// avoid keeping reference on to many strings
-			curEnv->DeleteLocalRef(TempString);
-			}"""%(name,name,name,errorMgntMem,name,name,errorMgntMemBis,name)
+				// avoid keeping reference on to many strings
+				curEnv->DeleteLocalRef(TempString);
+				}"""%(name,name,name,errorMgntMem,name,name,errorMgntMemBis,name)
+			else:
+				return """
+				// create java array of array of strings.
+				jobjectArray %s_ = curEnv->NewObjectArray( %sSize, curEnv->FindClass("[Ljava/lang/String;"), NULL);
+				if (%s_ == NULL)
+				{
+				%s
+				}
+
+				for ( int i = 0; i < %sSize; i++)
+				{
+				jobjectArray %sLocal = curEnv->NewObjectArray( %sSizeCol, stringArrayClass, NULL);
+				// convert each char * to java strings and fill the java array.
+				for ( int j = 0; j < %sSizeCol; j++) {
+				jstring TempString = curEnv->NewStringUTF( %s[i][j] );
+				
+				if (TempString == NULL)
+				{
+				%s
+				}
+
+				curEnv->SetObjectArrayElement( %sLocal, j, TempString);
+
+				// avoid keeping reference on to many strings
+				curEnv->DeleteLocalRef(TempString);
+				}
+				curEnv->SetObjectArrayElement(%s_, i, %sLocal);
+				curEnv->DeleteLocalRef(%sLocal);
+
+				}"""%(name,name,name,errorMgntMem,name,name,name,name,name,errorMgntMemBis,name,name,name,name)
+
 		else:
 			# Need to store is for the post processing (delete)
 			self.parameterName=name
@@ -125,20 +157,51 @@ class stringDataGiws(dataGiws):
 		str=JNIFrameWork().getExceptionCheckProfile()
 
 		if self.isArray():
-			return str+"""
-			jsize len = curEnv->GetArrayLength(res);
-			char **arrayOfString;
-                        arrayOfString = new char *[len + 1];
-			for (jsize i = 0; i < len; i++){
-			jstring resString = reinterpret_cast<jstring>(curEnv->GetObjectArrayElement(res, i));
-			const char *tempString = curEnv->GetStringUTFChars(resString, 0);
-			arrayOfString[i] = new char[strlen(tempString) + 1];
-
-			strcpy(arrayOfString[i], tempString);
-			curEnv->ReleaseStringUTFChars(resString, tempString);
-			curEnv->DeleteLocalRef(resString);
-			}
+			strCommon="""int lenRow;"""
+			strCommon+="""
+			lenRow = curEnv->GetArrayLength(res);
 			"""
+			if configGiws().getDisableReturnSize()==False:
+				# When the user want the size in the argument
+				strCommon+="""*lenRowReturned=lenRow;"""
+			    
+			if self.getDimensionArray() == 1:
+				return str+strCommon+"""
+				char **arrayOfString;
+				arrayOfString = new char *[lenRow];
+				for (jsize i = 0; i < lenRow; i++){
+				jstring resString = reinterpret_cast<jstring>(curEnv->GetObjectArrayElement(res, i));
+				const char *tempString = curEnv->GetStringUTFChars(resString, 0);
+				arrayOfString[i] = new char[strlen(tempString) + 1];
+	
+				strcpy(arrayOfString[i], tempString);
+				curEnv->ReleaseStringUTFChars(resString, tempString);
+				curEnv->DeleteLocalRef(resString);
+				}
+				"""
+			else:
+				str+="int lenCol;"
+				if configGiws().getDisableReturnSize()==False:
+					str+="""*lenColReturned=lenCol;"""
+				return str+strCommon+"""
+				char ***arrayOfString;
+				arrayOfString = new char **[lenRow];
+				for (jsize i = 0; i < lenRow; i++){ /* Line of the array */
+				jobjectArray resStringLine = reinterpret_cast<jobjectArray>(curEnv->GetObjectArrayElement(res, i));
+				lenCol = curEnv->GetArrayLength(resStringLine);
+				arrayOfString[i]=new char*[lenCol];
+				for (jsize j = 0; j < lenCol; j++){
+				jstring resString = reinterpret_cast<jstring>(curEnv->GetObjectArrayElement(resStringLine, j));
+				const char *tempString = curEnv->GetStringUTFChars(resString, 0);
+				arrayOfString[i][j] = new char[strlen(tempString) + 1];
+				strcpy(arrayOfString[i][j], tempString);
+				curEnv->ReleaseStringUTFChars(resString, tempString);
+				curEnv->DeleteLocalRef(resString);
+}
+				curEnv->DeleteLocalRef(resStringLine);
+				 }
+				"""
+
 		else:
 			if hasattr(self,"parameterName"):
 				str+="""curEnv->DeleteLocalRef(%s);"""%(self.parameterName+"_")
